kocher-tools
============

.. image:: https://www.travis-ci.com/kocherlab/kocher_tools.svg?branch=master
    :target: https://www.travis-ci.com/kocherlab/kocher_tools

Installation
------------

.. code-block:: bash

    conda install -c aewebb80 -c bioconda kocher_tools
